@@ -4,7 +4,14 @@ knitr::opts_chunk$set(message = FALSE, warning = FALSE)
 ## -----------------------------------------------------------------------------
 library(broom)
 library(tibble)
+library(ggplot2)
+library(dplyr)
+library(tidyr)
+library(purrr)
 
+theme_set(theme_minimal())
+
+## -----------------------------------------------------------------------------
 data(Orange)
 
 Orange <- as_tibble(Orange)
@@ -13,16 +20,10 @@ Orange
 ## -----------------------------------------------------------------------------
 cor(Orange$age, Orange$circumference)
 
-library(ggplot2)
-
-theme_set(theme_minimal())
-
 ggplot(Orange, aes(age, circumference, color = Tree)) +
   geom_line()
 
-## -----------------------------------------------------------------------------
-library(dplyr)
-
+## ---- message = FALSE, warning = FALSE----------------------------------------
 Orange %>% 
   group_by(Tree) %>%
   summarize(correlation = cor(age, circumference))
@@ -35,11 +36,8 @@ ct
 tidy(ct)
 
 ## -----------------------------------------------------------------------------
-library(tidyr)
-library(purrr)
-
 nested <- Orange %>% 
-  nest(-Tree)
+  nest(data = -Tree)
 
 ## -----------------------------------------------------------------------------
 nested %>% 
@@ -54,12 +52,12 @@ nested %>%
 
 ## -----------------------------------------------------------------------------
 Orange %>% 
-  nest(-Tree) %>% 
+  nest(data = -Tree) %>% 
   mutate(
     test = map(data, ~ cor.test(.x$age, .x$circumference)), # S3 list-col
     tidied = map(test, tidy)
   ) %>% 
-  unnest(tidied, .drop = TRUE)
+  unnest(tidied)
 
 ## -----------------------------------------------------------------------------
 lm_fit <- lm(age ~ circumference, data = Orange)
@@ -70,7 +68,7 @@ tidy(lm_fit)
 
 ## -----------------------------------------------------------------------------
 Orange %>%
-  nest(-Tree) %>% 
+  nest(data = -Tree) %>% 
   mutate(
     fit = map(data, ~ lm(age ~ circumference, data = .x)),
     tidied = map(fit, tidy)
@@ -83,7 +81,7 @@ mtcars <- as_tibble(mtcars)  # to play nicely with list-cols
 mtcars
 
 mtcars %>%
-  nest(-am) %>% 
+  nest(data = -am) %>% 
   mutate(
     fit = map(data, ~ lm(wt ~ mpg + qsec + gear, data = .x)),  # S3 list-col
     tidied = map(fit, tidy)
@@ -92,7 +90,7 @@ mtcars %>%
 
 ## -----------------------------------------------------------------------------
 regressions <- mtcars %>%
-  nest(-am) %>% 
+  nest(data = -am) %>% 
   mutate(
     fit = map(data, ~ lm(wt ~ mpg + qsec + gear, data = .x)),
     tidied = map(fit, tidy),
